# coding: utf-8

"""
    convertapi

    Convert API lets you effortlessly convert file formats and types.  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from cloudmersive_convert_api_client.api_client import ApiClient


class EditPdfApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def edit_pdf_add_annotations(self, request, **kwargs):  # noqa: E501
        """Add one or more PDF annotations, comments in the PDF document  # noqa: E501

        Adds one or more annotations, comments to a PDF document.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.edit_pdf_add_annotations(request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param AddPdfAnnotationRequest request: (required)
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.edit_pdf_add_annotations_with_http_info(request, **kwargs)  # noqa: E501
        else:
            (data) = self.edit_pdf_add_annotations_with_http_info(request, **kwargs)  # noqa: E501
            return data

    def edit_pdf_add_annotations_with_http_info(self, request, **kwargs):  # noqa: E501
        """Add one or more PDF annotations, comments in the PDF document  # noqa: E501

        Adds one or more annotations, comments to a PDF document.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.edit_pdf_add_annotations_with_http_info(request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param AddPdfAnnotationRequest request: (required)
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['request']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method edit_pdf_add_annotations" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'request' is set
        if ('request' not in params or
                params['request'] is None):
            raise ValueError("Missing the required parameter `request` when calling `edit_pdf_add_annotations`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'request' in params:
            body_params = params['request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/octet-stream'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'text/json', 'application/xml', 'text/xml', 'application/x-www-form-urlencoded'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Apikey']  # noqa: E501

        return self.api_client.call_api(
            '/convert/edit/pdf/annotations/add-item', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='str',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def edit_pdf_decrypt(self, password, input_file, **kwargs):  # noqa: E501
        """Decrypt and password-protect a PDF  # noqa: E501

        Decrypt a PDF document with a password.  Decrypted PDF will no longer require a password to open.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.edit_pdf_decrypt(password, input_file, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str password: Valid password for the PDF file (required)
        :param file input_file: Input file to perform the operation on. (required)
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.edit_pdf_decrypt_with_http_info(password, input_file, **kwargs)  # noqa: E501
        else:
            (data) = self.edit_pdf_decrypt_with_http_info(password, input_file, **kwargs)  # noqa: E501
            return data

    def edit_pdf_decrypt_with_http_info(self, password, input_file, **kwargs):  # noqa: E501
        """Decrypt and password-protect a PDF  # noqa: E501

        Decrypt a PDF document with a password.  Decrypted PDF will no longer require a password to open.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.edit_pdf_decrypt_with_http_info(password, input_file, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str password: Valid password for the PDF file (required)
        :param file input_file: Input file to perform the operation on. (required)
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['password', 'input_file']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method edit_pdf_decrypt" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'password' is set
        if ('password' not in params or
                params['password'] is None):
            raise ValueError("Missing the required parameter `password` when calling `edit_pdf_decrypt`")  # noqa: E501
        # verify the required parameter 'input_file' is set
        if ('input_file' not in params or
                params['input_file'] is None):
            raise ValueError("Missing the required parameter `input_file` when calling `edit_pdf_decrypt`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}
        if 'password' in params:
            header_params['password'] = params['password']  # noqa: E501

        form_params = []
        local_var_files = {}
        if 'input_file' in params:
            local_var_files['inputFile'] = params['input_file']  # noqa: E501

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/octet-stream'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['multipart/form-data'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Apikey']  # noqa: E501

        return self.api_client.call_api(
            '/convert/edit/pdf/decrypt', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='str',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def edit_pdf_delete_pages(self, input_file, page_start, page_end, **kwargs):  # noqa: E501
        """Remove, delete pages from a PDF document  # noqa: E501

        Remove one or more pages from a PDF document  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.edit_pdf_delete_pages(input_file, page_start, page_end, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param file input_file: Input file to perform the operation on. (required)
        :param int page_start: Page number (1 based) to start deleting pages from (inclusive). (required)
        :param int page_end: Page number (1 based) to stop deleting pages from (inclusive). (required)
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.edit_pdf_delete_pages_with_http_info(input_file, page_start, page_end, **kwargs)  # noqa: E501
        else:
            (data) = self.edit_pdf_delete_pages_with_http_info(input_file, page_start, page_end, **kwargs)  # noqa: E501
            return data

    def edit_pdf_delete_pages_with_http_info(self, input_file, page_start, page_end, **kwargs):  # noqa: E501
        """Remove, delete pages from a PDF document  # noqa: E501

        Remove one or more pages from a PDF document  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.edit_pdf_delete_pages_with_http_info(input_file, page_start, page_end, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param file input_file: Input file to perform the operation on. (required)
        :param int page_start: Page number (1 based) to start deleting pages from (inclusive). (required)
        :param int page_end: Page number (1 based) to stop deleting pages from (inclusive). (required)
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['input_file', 'page_start', 'page_end']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method edit_pdf_delete_pages" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'input_file' is set
        if ('input_file' not in params or
                params['input_file'] is None):
            raise ValueError("Missing the required parameter `input_file` when calling `edit_pdf_delete_pages`")  # noqa: E501
        # verify the required parameter 'page_start' is set
        if ('page_start' not in params or
                params['page_start'] is None):
            raise ValueError("Missing the required parameter `page_start` when calling `edit_pdf_delete_pages`")  # noqa: E501
        # verify the required parameter 'page_end' is set
        if ('page_end' not in params or
                params['page_end'] is None):
            raise ValueError("Missing the required parameter `page_end` when calling `edit_pdf_delete_pages`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}
        if 'page_start' in params:
            header_params['pageStart'] = params['page_start']  # noqa: E501
        if 'page_end' in params:
            header_params['pageEnd'] = params['page_end']  # noqa: E501

        form_params = []
        local_var_files = {}
        if 'input_file' in params:
            local_var_files['inputFile'] = params['input_file']  # noqa: E501

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/octet-stream'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['multipart/form-data'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Apikey']  # noqa: E501

        return self.api_client.call_api(
            '/convert/edit/pdf/pages/delete', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='str',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def edit_pdf_encrypt(self, input_file, **kwargs):  # noqa: E501
        """Encrypt and password-protect a PDF  # noqa: E501

        Encrypt a PDF document with a password.  Set an owner password to control owner (editor/creator) permissions, and set a user (reader) password to control the viewer of the PDF.  Set the password fields null to omit the given password.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.edit_pdf_encrypt(input_file, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param file input_file: Input file to perform the operation on. (required)
        :param str user_password: Password of a user (reader) of the PDF file
        :param str owner_password: Password of a owner (creator/editor) of the PDF file
        :param str encryption_key_length: Possible values are \"128\" (128-bit RC4 encryption) and \"256\" (256-bit AES encryption).  Default is 256.
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.edit_pdf_encrypt_with_http_info(input_file, **kwargs)  # noqa: E501
        else:
            (data) = self.edit_pdf_encrypt_with_http_info(input_file, **kwargs)  # noqa: E501
            return data

    def edit_pdf_encrypt_with_http_info(self, input_file, **kwargs):  # noqa: E501
        """Encrypt and password-protect a PDF  # noqa: E501

        Encrypt a PDF document with a password.  Set an owner password to control owner (editor/creator) permissions, and set a user (reader) password to control the viewer of the PDF.  Set the password fields null to omit the given password.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.edit_pdf_encrypt_with_http_info(input_file, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param file input_file: Input file to perform the operation on. (required)
        :param str user_password: Password of a user (reader) of the PDF file
        :param str owner_password: Password of a owner (creator/editor) of the PDF file
        :param str encryption_key_length: Possible values are \"128\" (128-bit RC4 encryption) and \"256\" (256-bit AES encryption).  Default is 256.
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['input_file', 'user_password', 'owner_password', 'encryption_key_length']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method edit_pdf_encrypt" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'input_file' is set
        if ('input_file' not in params or
                params['input_file'] is None):
            raise ValueError("Missing the required parameter `input_file` when calling `edit_pdf_encrypt`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}
        if 'user_password' in params:
            header_params['userPassword'] = params['user_password']  # noqa: E501
        if 'owner_password' in params:
            header_params['ownerPassword'] = params['owner_password']  # noqa: E501
        if 'encryption_key_length' in params:
            header_params['encryptionKeyLength'] = params['encryption_key_length']  # noqa: E501

        form_params = []
        local_var_files = {}
        if 'input_file' in params:
            local_var_files['inputFile'] = params['input_file']  # noqa: E501

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/octet-stream'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['multipart/form-data'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Apikey']  # noqa: E501

        return self.api_client.call_api(
            '/convert/edit/pdf/encrypt', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='str',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def edit_pdf_get_annotations(self, input_file, **kwargs):  # noqa: E501
        """Get PDF annotations, including comments in the document  # noqa: E501

        Enumerates the annotations, including comments and notes, in a PDF document.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.edit_pdf_get_annotations(input_file, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param file input_file: Input file to perform the operation on. (required)
        :return: GetPdfAnnotationsResult
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.edit_pdf_get_annotations_with_http_info(input_file, **kwargs)  # noqa: E501
        else:
            (data) = self.edit_pdf_get_annotations_with_http_info(input_file, **kwargs)  # noqa: E501
            return data

    def edit_pdf_get_annotations_with_http_info(self, input_file, **kwargs):  # noqa: E501
        """Get PDF annotations, including comments in the document  # noqa: E501

        Enumerates the annotations, including comments and notes, in a PDF document.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.edit_pdf_get_annotations_with_http_info(input_file, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param file input_file: Input file to perform the operation on. (required)
        :return: GetPdfAnnotationsResult
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['input_file']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method edit_pdf_get_annotations" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'input_file' is set
        if ('input_file' not in params or
                params['input_file'] is None):
            raise ValueError("Missing the required parameter `input_file` when calling `edit_pdf_get_annotations`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}
        if 'input_file' in params:
            local_var_files['inputFile'] = params['input_file']  # noqa: E501

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/octet-stream'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['multipart/form-data'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Apikey']  # noqa: E501

        return self.api_client.call_api(
            '/convert/edit/pdf/annotations/list', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='GetPdfAnnotationsResult',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def edit_pdf_get_form_fields(self, input_file, **kwargs):  # noqa: E501
        """Gets PDF Form fields and values  # noqa: E501

        Encrypt a PDF document with a password.  Set an owner password to control owner (editor/creator) permissions, and set a user (reader) password to control the viewer of the PDF.  Set the password fields null to omit the given password.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.edit_pdf_get_form_fields(input_file, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param file input_file: Input file to perform the operation on. (required)
        :return: PdfFormFields
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.edit_pdf_get_form_fields_with_http_info(input_file, **kwargs)  # noqa: E501
        else:
            (data) = self.edit_pdf_get_form_fields_with_http_info(input_file, **kwargs)  # noqa: E501
            return data

    def edit_pdf_get_form_fields_with_http_info(self, input_file, **kwargs):  # noqa: E501
        """Gets PDF Form fields and values  # noqa: E501

        Encrypt a PDF document with a password.  Set an owner password to control owner (editor/creator) permissions, and set a user (reader) password to control the viewer of the PDF.  Set the password fields null to omit the given password.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.edit_pdf_get_form_fields_with_http_info(input_file, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param file input_file: Input file to perform the operation on. (required)
        :return: PdfFormFields
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['input_file']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method edit_pdf_get_form_fields" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'input_file' is set
        if ('input_file' not in params or
                params['input_file'] is None):
            raise ValueError("Missing the required parameter `input_file` when calling `edit_pdf_get_form_fields`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}
        if 'input_file' in params:
            local_var_files['inputFile'] = params['input_file']  # noqa: E501

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/octet-stream'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['multipart/form-data'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Apikey']  # noqa: E501

        return self.api_client.call_api(
            '/convert/edit/pdf/form/get-fields', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='PdfFormFields',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def edit_pdf_get_metadata(self, input_file, **kwargs):  # noqa: E501
        """Get PDF document metadata  # noqa: E501

        Returns the metadata from the PDF document, including Title, Author, etc.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.edit_pdf_get_metadata(input_file, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param file input_file: Input file to perform the operation on. (required)
        :return: PdfMetadata
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.edit_pdf_get_metadata_with_http_info(input_file, **kwargs)  # noqa: E501
        else:
            (data) = self.edit_pdf_get_metadata_with_http_info(input_file, **kwargs)  # noqa: E501
            return data

    def edit_pdf_get_metadata_with_http_info(self, input_file, **kwargs):  # noqa: E501
        """Get PDF document metadata  # noqa: E501

        Returns the metadata from the PDF document, including Title, Author, etc.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.edit_pdf_get_metadata_with_http_info(input_file, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param file input_file: Input file to perform the operation on. (required)
        :return: PdfMetadata
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['input_file']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method edit_pdf_get_metadata" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'input_file' is set
        if ('input_file' not in params or
                params['input_file'] is None):
            raise ValueError("Missing the required parameter `input_file` when calling `edit_pdf_get_metadata`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}
        if 'input_file' in params:
            local_var_files['inputFile'] = params['input_file']  # noqa: E501

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json', 'application/xml', 'text/xml'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['multipart/form-data'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Apikey']  # noqa: E501

        return self.api_client.call_api(
            '/convert/edit/pdf/get-metadata', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='PdfMetadata',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def edit_pdf_get_pdf_text_by_pages(self, input_file, **kwargs):  # noqa: E501
        """Get text in a PDF document by page  # noqa: E501

        Gets the text in a PDF by page  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.edit_pdf_get_pdf_text_by_pages(input_file, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param file input_file: Input file to perform the operation on. (required)
        :param str text_formatting_mode: Optional; specify how whitespace should be handled when converting the document to text.  Possible values are 'preserveWhitespace' which will attempt to preserve whitespace in the document and relative positioning of text within the document, and 'minimizeWhitespace' which will not insert additional spaces into the document in most cases.  Default is 'preserveWhitespace'.
        :return: PdfTextByPageResult
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.edit_pdf_get_pdf_text_by_pages_with_http_info(input_file, **kwargs)  # noqa: E501
        else:
            (data) = self.edit_pdf_get_pdf_text_by_pages_with_http_info(input_file, **kwargs)  # noqa: E501
            return data

    def edit_pdf_get_pdf_text_by_pages_with_http_info(self, input_file, **kwargs):  # noqa: E501
        """Get text in a PDF document by page  # noqa: E501

        Gets the text in a PDF by page  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.edit_pdf_get_pdf_text_by_pages_with_http_info(input_file, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param file input_file: Input file to perform the operation on. (required)
        :param str text_formatting_mode: Optional; specify how whitespace should be handled when converting the document to text.  Possible values are 'preserveWhitespace' which will attempt to preserve whitespace in the document and relative positioning of text within the document, and 'minimizeWhitespace' which will not insert additional spaces into the document in most cases.  Default is 'preserveWhitespace'.
        :return: PdfTextByPageResult
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['input_file', 'text_formatting_mode']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method edit_pdf_get_pdf_text_by_pages" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'input_file' is set
        if ('input_file' not in params or
                params['input_file'] is None):
            raise ValueError("Missing the required parameter `input_file` when calling `edit_pdf_get_pdf_text_by_pages`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}
        if 'text_formatting_mode' in params:
            header_params['textFormattingMode'] = params['text_formatting_mode']  # noqa: E501

        form_params = []
        local_var_files = {}
        if 'input_file' in params:
            local_var_files['inputFile'] = params['input_file']  # noqa: E501

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json', 'application/xml', 'text/xml'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['multipart/form-data'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Apikey']  # noqa: E501

        return self.api_client.call_api(
            '/convert/edit/pdf/pages/get-text', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='PdfTextByPageResult',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def edit_pdf_insert_pages(self, source_file, destination_file, page_start_source, page_end_source, page_insert_before_desitnation, **kwargs):  # noqa: E501
        """Insert, copy pages from one PDF document into another  # noqa: E501

        Copy one or more pages from one PDF document (source document) and insert them into a second PDF document (destination document).  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.edit_pdf_insert_pages(source_file, destination_file, page_start_source, page_end_source, page_insert_before_desitnation, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param file source_file: Source PDF file to copy pages from. (required)
        :param file destination_file: Destination PDF file to copy pages into. (required)
        :param int page_start_source: Page number (1 based) to start copying pages from (inclusive) in the Source file. (required)
        :param int page_end_source: Page number (1 based) to stop copying pages pages from (inclusive) in the Source file. (required)
        :param int page_insert_before_desitnation: Page number (1 based) to insert the pages before in the Destination file. (required)
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.edit_pdf_insert_pages_with_http_info(source_file, destination_file, page_start_source, page_end_source, page_insert_before_desitnation, **kwargs)  # noqa: E501
        else:
            (data) = self.edit_pdf_insert_pages_with_http_info(source_file, destination_file, page_start_source, page_end_source, page_insert_before_desitnation, **kwargs)  # noqa: E501
            return data

    def edit_pdf_insert_pages_with_http_info(self, source_file, destination_file, page_start_source, page_end_source, page_insert_before_desitnation, **kwargs):  # noqa: E501
        """Insert, copy pages from one PDF document into another  # noqa: E501

        Copy one or more pages from one PDF document (source document) and insert them into a second PDF document (destination document).  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.edit_pdf_insert_pages_with_http_info(source_file, destination_file, page_start_source, page_end_source, page_insert_before_desitnation, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param file source_file: Source PDF file to copy pages from. (required)
        :param file destination_file: Destination PDF file to copy pages into. (required)
        :param int page_start_source: Page number (1 based) to start copying pages from (inclusive) in the Source file. (required)
        :param int page_end_source: Page number (1 based) to stop copying pages pages from (inclusive) in the Source file. (required)
        :param int page_insert_before_desitnation: Page number (1 based) to insert the pages before in the Destination file. (required)
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['source_file', 'destination_file', 'page_start_source', 'page_end_source', 'page_insert_before_desitnation']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method edit_pdf_insert_pages" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'source_file' is set
        if ('source_file' not in params or
                params['source_file'] is None):
            raise ValueError("Missing the required parameter `source_file` when calling `edit_pdf_insert_pages`")  # noqa: E501
        # verify the required parameter 'destination_file' is set
        if ('destination_file' not in params or
                params['destination_file'] is None):
            raise ValueError("Missing the required parameter `destination_file` when calling `edit_pdf_insert_pages`")  # noqa: E501
        # verify the required parameter 'page_start_source' is set
        if ('page_start_source' not in params or
                params['page_start_source'] is None):
            raise ValueError("Missing the required parameter `page_start_source` when calling `edit_pdf_insert_pages`")  # noqa: E501
        # verify the required parameter 'page_end_source' is set
        if ('page_end_source' not in params or
                params['page_end_source'] is None):
            raise ValueError("Missing the required parameter `page_end_source` when calling `edit_pdf_insert_pages`")  # noqa: E501
        # verify the required parameter 'page_insert_before_desitnation' is set
        if ('page_insert_before_desitnation' not in params or
                params['page_insert_before_desitnation'] is None):
            raise ValueError("Missing the required parameter `page_insert_before_desitnation` when calling `edit_pdf_insert_pages`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}
        if 'page_start_source' in params:
            header_params['pageStartSource'] = params['page_start_source']  # noqa: E501
        if 'page_end_source' in params:
            header_params['pageEndSource'] = params['page_end_source']  # noqa: E501
        if 'page_insert_before_desitnation' in params:
            header_params['pageInsertBeforeDesitnation'] = params['page_insert_before_desitnation']  # noqa: E501

        form_params = []
        local_var_files = {}
        if 'source_file' in params:
            local_var_files['sourceFile'] = params['source_file']  # noqa: E501
        if 'destination_file' in params:
            local_var_files['destinationFile'] = params['destination_file']  # noqa: E501

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/octet-stream'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['multipart/form-data'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Apikey']  # noqa: E501

        return self.api_client.call_api(
            '/convert/edit/pdf/pages/insert', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='str',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def edit_pdf_rasterize(self, input_file, **kwargs):  # noqa: E501
        """Rasterize a PDF to an image-based PDF  # noqa: E501

        Rasterize a PDF into an image-based PDF.  The output is a PDF where each page is comprised of a high-resolution image, with all text, figures and other components removed.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.edit_pdf_rasterize(input_file, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param file input_file: Input file to perform the operation on. (required)
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.edit_pdf_rasterize_with_http_info(input_file, **kwargs)  # noqa: E501
        else:
            (data) = self.edit_pdf_rasterize_with_http_info(input_file, **kwargs)  # noqa: E501
            return data

    def edit_pdf_rasterize_with_http_info(self, input_file, **kwargs):  # noqa: E501
        """Rasterize a PDF to an image-based PDF  # noqa: E501

        Rasterize a PDF into an image-based PDF.  The output is a PDF where each page is comprised of a high-resolution image, with all text, figures and other components removed.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.edit_pdf_rasterize_with_http_info(input_file, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param file input_file: Input file to perform the operation on. (required)
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['input_file']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method edit_pdf_rasterize" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'input_file' is set
        if ('input_file' not in params or
                params['input_file'] is None):
            raise ValueError("Missing the required parameter `input_file` when calling `edit_pdf_rasterize`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}
        if 'input_file' in params:
            local_var_files['inputFile'] = params['input_file']  # noqa: E501

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/octet-stream'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['multipart/form-data'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Apikey']  # noqa: E501

        return self.api_client.call_api(
            '/convert/edit/pdf/rasterize', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='str',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def edit_pdf_remove_all_annotations(self, input_file, **kwargs):  # noqa: E501
        """Remove all PDF annotations, including comments in the document  # noqa: E501

        Removes all of the annotations, including comments and notes, in a PDF document.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.edit_pdf_remove_all_annotations(input_file, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param file input_file: Input file to perform the operation on. (required)
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.edit_pdf_remove_all_annotations_with_http_info(input_file, **kwargs)  # noqa: E501
        else:
            (data) = self.edit_pdf_remove_all_annotations_with_http_info(input_file, **kwargs)  # noqa: E501
            return data

    def edit_pdf_remove_all_annotations_with_http_info(self, input_file, **kwargs):  # noqa: E501
        """Remove all PDF annotations, including comments in the document  # noqa: E501

        Removes all of the annotations, including comments and notes, in a PDF document.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.edit_pdf_remove_all_annotations_with_http_info(input_file, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param file input_file: Input file to perform the operation on. (required)
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['input_file']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method edit_pdf_remove_all_annotations" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'input_file' is set
        if ('input_file' not in params or
                params['input_file'] is None):
            raise ValueError("Missing the required parameter `input_file` when calling `edit_pdf_remove_all_annotations`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}
        if 'input_file' in params:
            local_var_files['inputFile'] = params['input_file']  # noqa: E501

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/octet-stream'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['multipart/form-data'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Apikey']  # noqa: E501

        return self.api_client.call_api(
            '/convert/edit/pdf/annotations/remove-all', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='str',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def edit_pdf_remove_annotation_item(self, input_file, annotation_index, **kwargs):  # noqa: E501
        """Remove a specific PDF annotation, comment in the document  # noqa: E501

        Removes a specific annotation in a PDF document, using the AnnotationIndex.  To enumerate AnnotationIndex for all of the annotations in the PDF document, use the /edit/pdf/annotations/list API.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.edit_pdf_remove_annotation_item(input_file, annotation_index, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param file input_file: Input file to perform the operation on. (required)
        :param int annotation_index: The 0-based index of the annotation in the document (required)
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.edit_pdf_remove_annotation_item_with_http_info(input_file, annotation_index, **kwargs)  # noqa: E501
        else:
            (data) = self.edit_pdf_remove_annotation_item_with_http_info(input_file, annotation_index, **kwargs)  # noqa: E501
            return data

    def edit_pdf_remove_annotation_item_with_http_info(self, input_file, annotation_index, **kwargs):  # noqa: E501
        """Remove a specific PDF annotation, comment in the document  # noqa: E501

        Removes a specific annotation in a PDF document, using the AnnotationIndex.  To enumerate AnnotationIndex for all of the annotations in the PDF document, use the /edit/pdf/annotations/list API.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.edit_pdf_remove_annotation_item_with_http_info(input_file, annotation_index, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param file input_file: Input file to perform the operation on. (required)
        :param int annotation_index: The 0-based index of the annotation in the document (required)
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['input_file', 'annotation_index']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method edit_pdf_remove_annotation_item" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'input_file' is set
        if ('input_file' not in params or
                params['input_file'] is None):
            raise ValueError("Missing the required parameter `input_file` when calling `edit_pdf_remove_annotation_item`")  # noqa: E501
        # verify the required parameter 'annotation_index' is set
        if ('annotation_index' not in params or
                params['annotation_index'] is None):
            raise ValueError("Missing the required parameter `annotation_index` when calling `edit_pdf_remove_annotation_item`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}
        if 'annotation_index' in params:
            header_params['annotationIndex'] = params['annotation_index']  # noqa: E501

        form_params = []
        local_var_files = {}
        if 'input_file' in params:
            local_var_files['inputFile'] = params['input_file']  # noqa: E501

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/octet-stream'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['multipart/form-data'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Apikey']  # noqa: E501

        return self.api_client.call_api(
            '/convert/edit/pdf/annotations/remove-item', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='str',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def edit_pdf_rotate_all_pages(self, input_file, rotation_angle, **kwargs):  # noqa: E501
        """Rotate all pages in a PDF document  # noqa: E501

        Rotate all of the pages in a PDF document by a multiple of 90 degrees  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.edit_pdf_rotate_all_pages(input_file, rotation_angle, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param file input_file: Input file to perform the operation on. (required)
        :param int rotation_angle: The angle to rotate the page in degrees, must be a multiple of 90 degrees, e.g. 90, 180, 270, or -90, -180, -270, etc. (required)
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.edit_pdf_rotate_all_pages_with_http_info(input_file, rotation_angle, **kwargs)  # noqa: E501
        else:
            (data) = self.edit_pdf_rotate_all_pages_with_http_info(input_file, rotation_angle, **kwargs)  # noqa: E501
            return data

    def edit_pdf_rotate_all_pages_with_http_info(self, input_file, rotation_angle, **kwargs):  # noqa: E501
        """Rotate all pages in a PDF document  # noqa: E501

        Rotate all of the pages in a PDF document by a multiple of 90 degrees  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.edit_pdf_rotate_all_pages_with_http_info(input_file, rotation_angle, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param file input_file: Input file to perform the operation on. (required)
        :param int rotation_angle: The angle to rotate the page in degrees, must be a multiple of 90 degrees, e.g. 90, 180, 270, or -90, -180, -270, etc. (required)
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['input_file', 'rotation_angle']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method edit_pdf_rotate_all_pages" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'input_file' is set
        if ('input_file' not in params or
                params['input_file'] is None):
            raise ValueError("Missing the required parameter `input_file` when calling `edit_pdf_rotate_all_pages`")  # noqa: E501
        # verify the required parameter 'rotation_angle' is set
        if ('rotation_angle' not in params or
                params['rotation_angle'] is None):
            raise ValueError("Missing the required parameter `rotation_angle` when calling `edit_pdf_rotate_all_pages`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}
        if 'rotation_angle' in params:
            header_params['rotationAngle'] = params['rotation_angle']  # noqa: E501

        form_params = []
        local_var_files = {}
        if 'input_file' in params:
            local_var_files['inputFile'] = params['input_file']  # noqa: E501

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/octet-stream'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['multipart/form-data'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Apikey']  # noqa: E501

        return self.api_client.call_api(
            '/convert/edit/pdf/pages/rotate/all', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='str',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def edit_pdf_rotate_page_range(self, input_file, rotation_angle, page_start, page_end, **kwargs):  # noqa: E501
        """Rotate a range, subset of pages in a PDF document  # noqa: E501

        Rotate a range of specific pages in a PDF document by a multiple of 90 degrees  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.edit_pdf_rotate_page_range(input_file, rotation_angle, page_start, page_end, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param file input_file: Input file to perform the operation on. (required)
        :param int rotation_angle: The angle to rotate the page in degrees, must be a multiple of 90 degrees, e.g. 90, 180, 270, or -90, -180, -270, etc. (required)
        :param int page_start: Page number (1 based) to start rotating pages from (inclusive). (required)
        :param int page_end: Page number (1 based) to stop rotating pages from (inclusive). (required)
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.edit_pdf_rotate_page_range_with_http_info(input_file, rotation_angle, page_start, page_end, **kwargs)  # noqa: E501
        else:
            (data) = self.edit_pdf_rotate_page_range_with_http_info(input_file, rotation_angle, page_start, page_end, **kwargs)  # noqa: E501
            return data

    def edit_pdf_rotate_page_range_with_http_info(self, input_file, rotation_angle, page_start, page_end, **kwargs):  # noqa: E501
        """Rotate a range, subset of pages in a PDF document  # noqa: E501

        Rotate a range of specific pages in a PDF document by a multiple of 90 degrees  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.edit_pdf_rotate_page_range_with_http_info(input_file, rotation_angle, page_start, page_end, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param file input_file: Input file to perform the operation on. (required)
        :param int rotation_angle: The angle to rotate the page in degrees, must be a multiple of 90 degrees, e.g. 90, 180, 270, or -90, -180, -270, etc. (required)
        :param int page_start: Page number (1 based) to start rotating pages from (inclusive). (required)
        :param int page_end: Page number (1 based) to stop rotating pages from (inclusive). (required)
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['input_file', 'rotation_angle', 'page_start', 'page_end']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method edit_pdf_rotate_page_range" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'input_file' is set
        if ('input_file' not in params or
                params['input_file'] is None):
            raise ValueError("Missing the required parameter `input_file` when calling `edit_pdf_rotate_page_range`")  # noqa: E501
        # verify the required parameter 'rotation_angle' is set
        if ('rotation_angle' not in params or
                params['rotation_angle'] is None):
            raise ValueError("Missing the required parameter `rotation_angle` when calling `edit_pdf_rotate_page_range`")  # noqa: E501
        # verify the required parameter 'page_start' is set
        if ('page_start' not in params or
                params['page_start'] is None):
            raise ValueError("Missing the required parameter `page_start` when calling `edit_pdf_rotate_page_range`")  # noqa: E501
        # verify the required parameter 'page_end' is set
        if ('page_end' not in params or
                params['page_end'] is None):
            raise ValueError("Missing the required parameter `page_end` when calling `edit_pdf_rotate_page_range`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}
        if 'rotation_angle' in params:
            header_params['rotationAngle'] = params['rotation_angle']  # noqa: E501
        if 'page_start' in params:
            header_params['pageStart'] = params['page_start']  # noqa: E501
        if 'page_end' in params:
            header_params['pageEnd'] = params['page_end']  # noqa: E501

        form_params = []
        local_var_files = {}
        if 'input_file' in params:
            local_var_files['inputFile'] = params['input_file']  # noqa: E501

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/octet-stream'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['multipart/form-data'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Apikey']  # noqa: E501

        return self.api_client.call_api(
            '/convert/edit/pdf/pages/rotate/page-range', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='str',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def edit_pdf_set_form_fields(self, field_values, **kwargs):  # noqa: E501
        """Sets ands fills PDF Form field values  # noqa: E501

        Fill in the form fields in a PDF form with specific values.  Use form/get-fields to enumerate the available fields and their data types in an input form.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.edit_pdf_set_form_fields(field_values, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param SetPdfFormFieldsRequest field_values: (required)
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.edit_pdf_set_form_fields_with_http_info(field_values, **kwargs)  # noqa: E501
        else:
            (data) = self.edit_pdf_set_form_fields_with_http_info(field_values, **kwargs)  # noqa: E501
            return data

    def edit_pdf_set_form_fields_with_http_info(self, field_values, **kwargs):  # noqa: E501
        """Sets ands fills PDF Form field values  # noqa: E501

        Fill in the form fields in a PDF form with specific values.  Use form/get-fields to enumerate the available fields and their data types in an input form.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.edit_pdf_set_form_fields_with_http_info(field_values, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param SetPdfFormFieldsRequest field_values: (required)
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['field_values']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method edit_pdf_set_form_fields" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'field_values' is set
        if ('field_values' not in params or
                params['field_values'] is None):
            raise ValueError("Missing the required parameter `field_values` when calling `edit_pdf_set_form_fields`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'field_values' in params:
            body_params = params['field_values']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/octet-stream'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'text/json', 'application/xml', 'text/xml', 'application/x-www-form-urlencoded'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Apikey']  # noqa: E501

        return self.api_client.call_api(
            '/convert/edit/pdf/form/set-fields', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='str',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def edit_pdf_set_metadata(self, request, **kwargs):  # noqa: E501
        """Sets PDF document metadata  # noqa: E501

        Sets (writes) metadata into the input PDF document, including Title, Author, etc.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.edit_pdf_set_metadata(request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param SetPdfMetadataRequest request: (required)
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.edit_pdf_set_metadata_with_http_info(request, **kwargs)  # noqa: E501
        else:
            (data) = self.edit_pdf_set_metadata_with_http_info(request, **kwargs)  # noqa: E501
            return data

    def edit_pdf_set_metadata_with_http_info(self, request, **kwargs):  # noqa: E501
        """Sets PDF document metadata  # noqa: E501

        Sets (writes) metadata into the input PDF document, including Title, Author, etc.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.edit_pdf_set_metadata_with_http_info(request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param SetPdfMetadataRequest request: (required)
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['request']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method edit_pdf_set_metadata" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'request' is set
        if ('request' not in params or
                params['request'] is None):
            raise ValueError("Missing the required parameter `request` when calling `edit_pdf_set_metadata`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'request' in params:
            body_params = params['request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/octet-stream'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'text/json', 'application/xml', 'text/xml', 'application/x-www-form-urlencoded'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Apikey']  # noqa: E501

        return self.api_client.call_api(
            '/convert/edit/pdf/set-metadata', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='str',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def edit_pdf_set_permissions(self, owner_password, user_password, input_file, **kwargs):  # noqa: E501
        """Encrypt, password-protect and set restricted permissions on a PDF  # noqa: E501

        Encrypt a PDF document with a password, and set permissions on the PDF.  Set an owner password to control owner (editor/creator) permissions [required], and set a user (reader) password to control the viewer of the PDF [optional].  Set the reader password to null to omit the password.  Restrict or allow printing, copying content, document assembly, editing (read-only), form filling, modification of annotations, and degraded printing through document Digital Rights Management (DRM).  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.edit_pdf_set_permissions(owner_password, user_password, input_file, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str owner_password: Password of a owner (creator/editor) of the PDF file (required) (required)
        :param str user_password: Password of a user (reader) of the PDF file (optional) (required)
        :param file input_file: Input file to perform the operation on. (required)
        :param str encryption_key_length: Possible values are \"128\" (128-bit RC4 encryption) and \"256\" (256-bit AES encryption).  Default is 256.
        :param bool allow_printing: Set to false to disable printing through DRM.  Default is true.
        :param bool allow_document_assembly: Set to false to disable document assembly through DRM.  Default is true.
        :param bool allow_content_extraction: Set to false to disable copying/extracting content out of the PDF through DRM.  Default is true.
        :param bool allow_form_filling: Set to false to disable filling out form fields in the PDF through DRM.  Default is true.
        :param bool allow_editing: Set to false to disable editing in the PDF through DRM (making the PDF read-only).  Default is true.
        :param bool allow_annotations: Set to false to disable annotations and editing of annotations in the PDF through DRM.  Default is true.
        :param bool allow_degraded_printing: Set to false to disable degraded printing of the PDF through DRM.  Default is true.
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.edit_pdf_set_permissions_with_http_info(owner_password, user_password, input_file, **kwargs)  # noqa: E501
        else:
            (data) = self.edit_pdf_set_permissions_with_http_info(owner_password, user_password, input_file, **kwargs)  # noqa: E501
            return data

    def edit_pdf_set_permissions_with_http_info(self, owner_password, user_password, input_file, **kwargs):  # noqa: E501
        """Encrypt, password-protect and set restricted permissions on a PDF  # noqa: E501

        Encrypt a PDF document with a password, and set permissions on the PDF.  Set an owner password to control owner (editor/creator) permissions [required], and set a user (reader) password to control the viewer of the PDF [optional].  Set the reader password to null to omit the password.  Restrict or allow printing, copying content, document assembly, editing (read-only), form filling, modification of annotations, and degraded printing through document Digital Rights Management (DRM).  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.edit_pdf_set_permissions_with_http_info(owner_password, user_password, input_file, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str owner_password: Password of a owner (creator/editor) of the PDF file (required) (required)
        :param str user_password: Password of a user (reader) of the PDF file (optional) (required)
        :param file input_file: Input file to perform the operation on. (required)
        :param str encryption_key_length: Possible values are \"128\" (128-bit RC4 encryption) and \"256\" (256-bit AES encryption).  Default is 256.
        :param bool allow_printing: Set to false to disable printing through DRM.  Default is true.
        :param bool allow_document_assembly: Set to false to disable document assembly through DRM.  Default is true.
        :param bool allow_content_extraction: Set to false to disable copying/extracting content out of the PDF through DRM.  Default is true.
        :param bool allow_form_filling: Set to false to disable filling out form fields in the PDF through DRM.  Default is true.
        :param bool allow_editing: Set to false to disable editing in the PDF through DRM (making the PDF read-only).  Default is true.
        :param bool allow_annotations: Set to false to disable annotations and editing of annotations in the PDF through DRM.  Default is true.
        :param bool allow_degraded_printing: Set to false to disable degraded printing of the PDF through DRM.  Default is true.
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['owner_password', 'user_password', 'input_file', 'encryption_key_length', 'allow_printing', 'allow_document_assembly', 'allow_content_extraction', 'allow_form_filling', 'allow_editing', 'allow_annotations', 'allow_degraded_printing']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method edit_pdf_set_permissions" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'owner_password' is set
        if ('owner_password' not in params or
                params['owner_password'] is None):
            raise ValueError("Missing the required parameter `owner_password` when calling `edit_pdf_set_permissions`")  # noqa: E501
        # verify the required parameter 'user_password' is set
        if ('user_password' not in params or
                params['user_password'] is None):
            raise ValueError("Missing the required parameter `user_password` when calling `edit_pdf_set_permissions`")  # noqa: E501
        # verify the required parameter 'input_file' is set
        if ('input_file' not in params or
                params['input_file'] is None):
            raise ValueError("Missing the required parameter `input_file` when calling `edit_pdf_set_permissions`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}
        if 'owner_password' in params:
            header_params['ownerPassword'] = params['owner_password']  # noqa: E501
        if 'user_password' in params:
            header_params['userPassword'] = params['user_password']  # noqa: E501
        if 'encryption_key_length' in params:
            header_params['encryptionKeyLength'] = params['encryption_key_length']  # noqa: E501
        if 'allow_printing' in params:
            header_params['allowPrinting'] = params['allow_printing']  # noqa: E501
        if 'allow_document_assembly' in params:
            header_params['allowDocumentAssembly'] = params['allow_document_assembly']  # noqa: E501
        if 'allow_content_extraction' in params:
            header_params['allowContentExtraction'] = params['allow_content_extraction']  # noqa: E501
        if 'allow_form_filling' in params:
            header_params['allowFormFilling'] = params['allow_form_filling']  # noqa: E501
        if 'allow_editing' in params:
            header_params['allowEditing'] = params['allow_editing']  # noqa: E501
        if 'allow_annotations' in params:
            header_params['allowAnnotations'] = params['allow_annotations']  # noqa: E501
        if 'allow_degraded_printing' in params:
            header_params['allowDegradedPrinting'] = params['allow_degraded_printing']  # noqa: E501

        form_params = []
        local_var_files = {}
        if 'input_file' in params:
            local_var_files['inputFile'] = params['input_file']  # noqa: E501

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/octet-stream'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['multipart/form-data'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Apikey']  # noqa: E501

        return self.api_client.call_api(
            '/convert/edit/pdf/encrypt/set-permissions', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='str',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def edit_pdf_watermark_text(self, watermark_text, input_file, **kwargs):  # noqa: E501
        """Add a text watermark to a PDF  # noqa: E501

        Adds a text watermark to a PDF  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.edit_pdf_watermark_text(watermark_text, input_file, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str watermark_text: Watermark text to add to the PDF (required) (required)
        :param file input_file: Input file to perform the operation on. (required)
        :param str font_name: Font Family Name for the watermark text; default is Times New Roman
        :param float font_size: Font Size in points of the text; default is 150
        :param str font_color: Font color in hexadecimal or HTML color name; default is Red
        :param float font_transparency: Font transparency between 0.0 (completely transparent) to 1.0 (fully opaque); default is 0.5
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.edit_pdf_watermark_text_with_http_info(watermark_text, input_file, **kwargs)  # noqa: E501
        else:
            (data) = self.edit_pdf_watermark_text_with_http_info(watermark_text, input_file, **kwargs)  # noqa: E501
            return data

    def edit_pdf_watermark_text_with_http_info(self, watermark_text, input_file, **kwargs):  # noqa: E501
        """Add a text watermark to a PDF  # noqa: E501

        Adds a text watermark to a PDF  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.edit_pdf_watermark_text_with_http_info(watermark_text, input_file, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str watermark_text: Watermark text to add to the PDF (required) (required)
        :param file input_file: Input file to perform the operation on. (required)
        :param str font_name: Font Family Name for the watermark text; default is Times New Roman
        :param float font_size: Font Size in points of the text; default is 150
        :param str font_color: Font color in hexadecimal or HTML color name; default is Red
        :param float font_transparency: Font transparency between 0.0 (completely transparent) to 1.0 (fully opaque); default is 0.5
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['watermark_text', 'input_file', 'font_name', 'font_size', 'font_color', 'font_transparency']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method edit_pdf_watermark_text" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'watermark_text' is set
        if ('watermark_text' not in params or
                params['watermark_text'] is None):
            raise ValueError("Missing the required parameter `watermark_text` when calling `edit_pdf_watermark_text`")  # noqa: E501
        # verify the required parameter 'input_file' is set
        if ('input_file' not in params or
                params['input_file'] is None):
            raise ValueError("Missing the required parameter `input_file` when calling `edit_pdf_watermark_text`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}
        if 'watermark_text' in params:
            header_params['watermarkText'] = params['watermark_text']  # noqa: E501
        if 'font_name' in params:
            header_params['fontName'] = params['font_name']  # noqa: E501
        if 'font_size' in params:
            header_params['fontSize'] = params['font_size']  # noqa: E501
        if 'font_color' in params:
            header_params['fontColor'] = params['font_color']  # noqa: E501
        if 'font_transparency' in params:
            header_params['fontTransparency'] = params['font_transparency']  # noqa: E501

        form_params = []
        local_var_files = {}
        if 'input_file' in params:
            local_var_files['inputFile'] = params['input_file']  # noqa: E501

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/octet-stream'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['multipart/form-data'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Apikey']  # noqa: E501

        return self.api_client.call_api(
            '/convert/edit/pdf/watermark/text', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='str',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    convertapi

    Convert API lets you effortlessly convert file formats and types.  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class SetFormFieldValue(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'field_name': 'str',
        'text_value': 'str',
        'checkbox_value': 'bool',
        'combo_box_selected_index': 'int'
    }

    attribute_map = {
        'field_name': 'FieldName',
        'text_value': 'TextValue',
        'checkbox_value': 'CheckboxValue',
        'combo_box_selected_index': 'ComboBoxSelectedIndex'
    }

    def __init__(self, field_name=None, text_value=None, checkbox_value=None, combo_box_selected_index=None):  # noqa: E501
        """SetFormFieldValue - a model defined in Swagger"""  # noqa: E501

        self._field_name = None
        self._text_value = None
        self._checkbox_value = None
        self._combo_box_selected_index = None
        self.discriminator = None

        if field_name is not None:
            self.field_name = field_name
        if text_value is not None:
            self.text_value = text_value
        if checkbox_value is not None:
            self.checkbox_value = checkbox_value
        if combo_box_selected_index is not None:
            self.combo_box_selected_index = combo_box_selected_index

    @property
    def field_name(self):
        """Gets the field_name of this SetFormFieldValue.  # noqa: E501

        Name of the field to set; you can call /convert/edit/pdf/form/get-fields to enumerate field names in a form  # noqa: E501

        :return: The field_name of this SetFormFieldValue.  # noqa: E501
        :rtype: str
        """
        return self._field_name

    @field_name.setter
    def field_name(self, field_name):
        """Sets the field_name of this SetFormFieldValue.

        Name of the field to set; you can call /convert/edit/pdf/form/get-fields to enumerate field names in a form  # noqa: E501

        :param field_name: The field_name of this SetFormFieldValue.  # noqa: E501
        :type: str
        """

        self._field_name = field_name

    @property
    def text_value(self):
        """Gets the text_value of this SetFormFieldValue.  # noqa: E501

        For fields of type Text, the text value to put into the field  # noqa: E501

        :return: The text_value of this SetFormFieldValue.  # noqa: E501
        :rtype: str
        """
        return self._text_value

    @text_value.setter
    def text_value(self, text_value):
        """Sets the text_value of this SetFormFieldValue.

        For fields of type Text, the text value to put into the field  # noqa: E501

        :param text_value: The text_value of this SetFormFieldValue.  # noqa: E501
        :type: str
        """

        self._text_value = text_value

    @property
    def checkbox_value(self):
        """Gets the checkbox_value of this SetFormFieldValue.  # noqa: E501

        For fields of type Checkbox, the value to put into the field  # noqa: E501

        :return: The checkbox_value of this SetFormFieldValue.  # noqa: E501
        :rtype: bool
        """
        return self._checkbox_value

    @checkbox_value.setter
    def checkbox_value(self, checkbox_value):
        """Sets the checkbox_value of this SetFormFieldValue.

        For fields of type Checkbox, the value to put into the field  # noqa: E501

        :param checkbox_value: The checkbox_value of this SetFormFieldValue.  # noqa: E501
        :type: bool
        """

        self._checkbox_value = checkbox_value

    @property
    def combo_box_selected_index(self):
        """Gets the combo_box_selected_index of this SetFormFieldValue.  # noqa: E501

        For fields of type ComboBox; specifies the selected index of the combo box selection  # noqa: E501

        :return: The combo_box_selected_index of this SetFormFieldValue.  # noqa: E501
        :rtype: int
        """
        return self._combo_box_selected_index

    @combo_box_selected_index.setter
    def combo_box_selected_index(self, combo_box_selected_index):
        """Sets the combo_box_selected_index of this SetFormFieldValue.

        For fields of type ComboBox; specifies the selected index of the combo box selection  # noqa: E501

        :param combo_box_selected_index: The combo_box_selected_index of this SetFormFieldValue.  # noqa: E501
        :type: int
        """

        self._combo_box_selected_index = combo_box_selected_index

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(SetFormFieldValue, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SetFormFieldValue):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    convertapi

    Convert API lets you effortlessly convert file formats and types.  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class DocxTable(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'table_id': 'str',
        'path': 'str',
        'width': 'str',
        'width_type': 'str',
        'table_rows': 'list[DocxTableRow]',
        'top_border_type': 'str',
        'top_border_size': 'int',
        'top_border_space': 'int',
        'top_border_color': 'str',
        'bottom_border_type': 'str',
        'bottom_border_size': 'int',
        'bottom_border_space': 'int',
        'bottom_border_color': 'str',
        'left_border_type': 'str',
        'left_border_size': 'int',
        'left_border_space': 'int',
        'left_border_color': 'str',
        'right_border_type': 'str',
        'right_border_size': 'int',
        'right_border_space': 'int',
        'right_border_color': 'str',
        'cell_horizontal_border_type': 'str',
        'cell_horizontal_border_size': 'int',
        'cell_horizontal_border_space': 'int',
        'cell_horizontal_border_color': 'str',
        'cell_vertical_border_type': 'str',
        'cell_vertical_border_size': 'int',
        'cell_vertical_border_space': 'int',
        'cell_vertical_border_color': 'str',
        'start_border_type': 'str',
        'start_border_size': 'int',
        'start_border_space': 'int',
        'start_border_color': 'str',
        'end_border_type': 'str',
        'end_border_size': 'int',
        'end_border_space': 'int',
        'end_border_color': 'str',
        'table_indentation_mode': 'str',
        'table_indentation_width': 'int'
    }

    attribute_map = {
        'table_id': 'TableID',
        'path': 'Path',
        'width': 'Width',
        'width_type': 'WidthType',
        'table_rows': 'TableRows',
        'top_border_type': 'TopBorderType',
        'top_border_size': 'TopBorderSize',
        'top_border_space': 'TopBorderSpace',
        'top_border_color': 'TopBorderColor',
        'bottom_border_type': 'BottomBorderType',
        'bottom_border_size': 'BottomBorderSize',
        'bottom_border_space': 'BottomBorderSpace',
        'bottom_border_color': 'BottomBorderColor',
        'left_border_type': 'LeftBorderType',
        'left_border_size': 'LeftBorderSize',
        'left_border_space': 'LeftBorderSpace',
        'left_border_color': 'LeftBorderColor',
        'right_border_type': 'RightBorderType',
        'right_border_size': 'RightBorderSize',
        'right_border_space': 'RightBorderSpace',
        'right_border_color': 'RightBorderColor',
        'cell_horizontal_border_type': 'CellHorizontalBorderType',
        'cell_horizontal_border_size': 'CellHorizontalBorderSize',
        'cell_horizontal_border_space': 'CellHorizontalBorderSpace',
        'cell_horizontal_border_color': 'CellHorizontalBorderColor',
        'cell_vertical_border_type': 'CellVerticalBorderType',
        'cell_vertical_border_size': 'CellVerticalBorderSize',
        'cell_vertical_border_space': 'CellVerticalBorderSpace',
        'cell_vertical_border_color': 'CellVerticalBorderColor',
        'start_border_type': 'StartBorderType',
        'start_border_size': 'StartBorderSize',
        'start_border_space': 'StartBorderSpace',
        'start_border_color': 'StartBorderColor',
        'end_border_type': 'EndBorderType',
        'end_border_size': 'EndBorderSize',
        'end_border_space': 'EndBorderSpace',
        'end_border_color': 'EndBorderColor',
        'table_indentation_mode': 'TableIndentationMode',
        'table_indentation_width': 'TableIndentationWidth'
    }

    def __init__(self, table_id=None, path=None, width=None, width_type=None, table_rows=None, top_border_type=None, top_border_size=None, top_border_space=None, top_border_color=None, bottom_border_type=None, bottom_border_size=None, bottom_border_space=None, bottom_border_color=None, left_border_type=None, left_border_size=None, left_border_space=None, left_border_color=None, right_border_type=None, right_border_size=None, right_border_space=None, right_border_color=None, cell_horizontal_border_type=None, cell_horizontal_border_size=None, cell_horizontal_border_space=None, cell_horizontal_border_color=None, cell_vertical_border_type=None, cell_vertical_border_size=None, cell_vertical_border_space=None, cell_vertical_border_color=None, start_border_type=None, start_border_size=None, start_border_space=None, start_border_color=None, end_border_type=None, end_border_size=None, end_border_space=None, end_border_color=None, table_indentation_mode=None, table_indentation_width=None):  # noqa: E501
        """DocxTable - a model defined in Swagger"""  # noqa: E501

        self._table_id = None
        self._path = None
        self._width = None
        self._width_type = None
        self._table_rows = None
        self._top_border_type = None
        self._top_border_size = None
        self._top_border_space = None
        self._top_border_color = None
        self._bottom_border_type = None
        self._bottom_border_size = None
        self._bottom_border_space = None
        self._bottom_border_color = None
        self._left_border_type = None
        self._left_border_size = None
        self._left_border_space = None
        self._left_border_color = None
        self._right_border_type = None
        self._right_border_size = None
        self._right_border_space = None
        self._right_border_color = None
        self._cell_horizontal_border_type = None
        self._cell_horizontal_border_size = None
        self._cell_horizontal_border_space = None
        self._cell_horizontal_border_color = None
        self._cell_vertical_border_type = None
        self._cell_vertical_border_size = None
        self._cell_vertical_border_space = None
        self._cell_vertical_border_color = None
        self._start_border_type = None
        self._start_border_size = None
        self._start_border_space = None
        self._start_border_color = None
        self._end_border_type = None
        self._end_border_size = None
        self._end_border_space = None
        self._end_border_color = None
        self._table_indentation_mode = None
        self._table_indentation_width = None
        self.discriminator = None

        if table_id is not None:
            self.table_id = table_id
        if path is not None:
            self.path = path
        if width is not None:
            self.width = width
        if width_type is not None:
            self.width_type = width_type
        if table_rows is not None:
            self.table_rows = table_rows
        if top_border_type is not None:
            self.top_border_type = top_border_type
        if top_border_size is not None:
            self.top_border_size = top_border_size
        if top_border_space is not None:
            self.top_border_space = top_border_space
        if top_border_color is not None:
            self.top_border_color = top_border_color
        if bottom_border_type is not None:
            self.bottom_border_type = bottom_border_type
        if bottom_border_size is not None:
            self.bottom_border_size = bottom_border_size
        if bottom_border_space is not None:
            self.bottom_border_space = bottom_border_space
        if bottom_border_color is not None:
            self.bottom_border_color = bottom_border_color
        if left_border_type is not None:
            self.left_border_type = left_border_type
        if left_border_size is not None:
            self.left_border_size = left_border_size
        if left_border_space is not None:
            self.left_border_space = left_border_space
        if left_border_color is not None:
            self.left_border_color = left_border_color
        if right_border_type is not None:
            self.right_border_type = right_border_type
        if right_border_size is not None:
            self.right_border_size = right_border_size
        if right_border_space is not None:
            self.right_border_space = right_border_space
        if right_border_color is not None:
            self.right_border_color = right_border_color
        if cell_horizontal_border_type is not None:
            self.cell_horizontal_border_type = cell_horizontal_border_type
        if cell_horizontal_border_size is not None:
            self.cell_horizontal_border_size = cell_horizontal_border_size
        if cell_horizontal_border_space is not None:
            self.cell_horizontal_border_space = cell_horizontal_border_space
        if cell_horizontal_border_color is not None:
            self.cell_horizontal_border_color = cell_horizontal_border_color
        if cell_vertical_border_type is not None:
            self.cell_vertical_border_type = cell_vertical_border_type
        if cell_vertical_border_size is not None:
            self.cell_vertical_border_size = cell_vertical_border_size
        if cell_vertical_border_space is not None:
            self.cell_vertical_border_space = cell_vertical_border_space
        if cell_vertical_border_color is not None:
            self.cell_vertical_border_color = cell_vertical_border_color
        if start_border_type is not None:
            self.start_border_type = start_border_type
        if start_border_size is not None:
            self.start_border_size = start_border_size
        if start_border_space is not None:
            self.start_border_space = start_border_space
        if start_border_color is not None:
            self.start_border_color = start_border_color
        if end_border_type is not None:
            self.end_border_type = end_border_type
        if end_border_size is not None:
            self.end_border_size = end_border_size
        if end_border_space is not None:
            self.end_border_space = end_border_space
        if end_border_color is not None:
            self.end_border_color = end_border_color
        if table_indentation_mode is not None:
            self.table_indentation_mode = table_indentation_mode
        if table_indentation_width is not None:
            self.table_indentation_width = table_indentation_width

    @property
    def table_id(self):
        """Gets the table_id of this DocxTable.  # noqa: E501

        The ID of the table; leave blank for new tables  # noqa: E501

        :return: The table_id of this DocxTable.  # noqa: E501
        :rtype: str
        """
        return self._table_id

    @table_id.setter
    def table_id(self, table_id):
        """Sets the table_id of this DocxTable.

        The ID of the table; leave blank for new tables  # noqa: E501

        :param table_id: The table_id of this DocxTable.  # noqa: E501
        :type: str
        """

        self._table_id = table_id

    @property
    def path(self):
        """Gets the path of this DocxTable.  # noqa: E501

        The Path of the location of this table object; leave blank for new tables  # noqa: E501

        :return: The path of this DocxTable.  # noqa: E501
        :rtype: str
        """
        return self._path

    @path.setter
    def path(self, path):
        """Sets the path of this DocxTable.

        The Path of the location of this table object; leave blank for new tables  # noqa: E501

        :param path: The path of this DocxTable.  # noqa: E501
        :type: str
        """

        self._path = path

    @property
    def width(self):
        """Gets the width of this DocxTable.  # noqa: E501

        The Width of the table, or 0 if not specified  # noqa: E501

        :return: The width of this DocxTable.  # noqa: E501
        :rtype: str
        """
        return self._width

    @width.setter
    def width(self, width):
        """Sets the width of this DocxTable.

        The Width of the table, or 0 if not specified  # noqa: E501

        :param width: The width of this DocxTable.  # noqa: E501
        :type: str
        """

        self._width = width

    @property
    def width_type(self):
        """Gets the width_type of this DocxTable.  # noqa: E501

        The Width configuration type of the table  # noqa: E501

        :return: The width_type of this DocxTable.  # noqa: E501
        :rtype: str
        """
        return self._width_type

    @width_type.setter
    def width_type(self, width_type):
        """Sets the width_type of this DocxTable.

        The Width configuration type of the table  # noqa: E501

        :param width_type: The width_type of this DocxTable.  # noqa: E501
        :type: str
        """

        self._width_type = width_type

    @property
    def table_rows(self):
        """Gets the table_rows of this DocxTable.  # noqa: E501

        Rows in the table; this is where the contents is located  # noqa: E501

        :return: The table_rows of this DocxTable.  # noqa: E501
        :rtype: list[DocxTableRow]
        """
        return self._table_rows

    @table_rows.setter
    def table_rows(self, table_rows):
        """Sets the table_rows of this DocxTable.

        Rows in the table; this is where the contents is located  # noqa: E501

        :param table_rows: The table_rows of this DocxTable.  # noqa: E501
        :type: list[DocxTableRow]
        """

        self._table_rows = table_rows

    @property
    def top_border_type(self):
        """Gets the top_border_type of this DocxTable.  # noqa: E501

        Type for the top border - can be a Single, DashDotStroked, Dashed, DashSmallGap, DotDash, DotDotDash, Dotted, Double, DoubleWave, Inset, Nil, None, Outset, Thick, ThickThinLargeGap, ThickThinMediumGap, ThickThinSmallGap, ThinThickLargeGap, ThinThickMediumGap, ThinThickSmallGap, ThinThickThinLargeGap, ThinThickThinMediumGap, ThinThickThinSmallGap, ThreeDEmboss, ThreeDEngrave, Triple, Wave  # noqa: E501

        :return: The top_border_type of this DocxTable.  # noqa: E501
        :rtype: str
        """
        return self._top_border_type

    @top_border_type.setter
    def top_border_type(self, top_border_type):
        """Sets the top_border_type of this DocxTable.

        Type for the top border - can be a Single, DashDotStroked, Dashed, DashSmallGap, DotDash, DotDotDash, Dotted, Double, DoubleWave, Inset, Nil, None, Outset, Thick, ThickThinLargeGap, ThickThinMediumGap, ThickThinSmallGap, ThinThickLargeGap, ThinThickMediumGap, ThinThickSmallGap, ThinThickThinLargeGap, ThinThickThinMediumGap, ThinThickThinSmallGap, ThreeDEmboss, ThreeDEngrave, Triple, Wave  # noqa: E501

        :param top_border_type: The top_border_type of this DocxTable.  # noqa: E501
        :type: str
        """

        self._top_border_type = top_border_type

    @property
    def top_border_size(self):
        """Gets the top_border_size of this DocxTable.  # noqa: E501

        Width of the border in points (1/72nd of an inch)  # noqa: E501

        :return: The top_border_size of this DocxTable.  # noqa: E501
        :rtype: int
        """
        return self._top_border_size

    @top_border_size.setter
    def top_border_size(self, top_border_size):
        """Sets the top_border_size of this DocxTable.

        Width of the border in points (1/72nd of an inch)  # noqa: E501

        :param top_border_size: The top_border_size of this DocxTable.  # noqa: E501
        :type: int
        """

        self._top_border_size = top_border_size

    @property
    def top_border_space(self):
        """Gets the top_border_space of this DocxTable.  # noqa: E501

        Spacing around the border in points (1/72nd of an inch)  # noqa: E501

        :return: The top_border_space of this DocxTable.  # noqa: E501
        :rtype: int
        """
        return self._top_border_space

    @top_border_space.setter
    def top_border_space(self, top_border_space):
        """Sets the top_border_space of this DocxTable.

        Spacing around the border in points (1/72nd of an inch)  # noqa: E501

        :param top_border_space: The top_border_space of this DocxTable.  # noqa: E501
        :type: int
        """

        self._top_border_space = top_border_space

    @property
    def top_border_color(self):
        """Gets the top_border_color of this DocxTable.  # noqa: E501

        HTML-style color hex value (do not include a #)  # noqa: E501

        :return: The top_border_color of this DocxTable.  # noqa: E501
        :rtype: str
        """
        return self._top_border_color

    @top_border_color.setter
    def top_border_color(self, top_border_color):
        """Sets the top_border_color of this DocxTable.

        HTML-style color hex value (do not include a #)  # noqa: E501

        :param top_border_color: The top_border_color of this DocxTable.  # noqa: E501
        :type: str
        """

        self._top_border_color = top_border_color

    @property
    def bottom_border_type(self):
        """Gets the bottom_border_type of this DocxTable.  # noqa: E501

        Type for the bottom border - can be a Single, DashDotStroked, Dashed, DashSmallGap, DotDash, DotDotDash, Dotted, Double, DoubleWave, Inset, Nil, None, Outset, Thick, ThickThinLargeGap, ThickThinMediumGap, ThickThinSmallGap, ThinThickLargeGap, ThinThickMediumGap, ThinThickSmallGap, ThinThickThinLargeGap, ThinThickThinMediumGap, ThinThickThinSmallGap, ThreeDEmboss, ThreeDEngrave, Triple, Wave  # noqa: E501

        :return: The bottom_border_type of this DocxTable.  # noqa: E501
        :rtype: str
        """
        return self._bottom_border_type

    @bottom_border_type.setter
    def bottom_border_type(self, bottom_border_type):
        """Sets the bottom_border_type of this DocxTable.

        Type for the bottom border - can be a Single, DashDotStroked, Dashed, DashSmallGap, DotDash, DotDotDash, Dotted, Double, DoubleWave, Inset, Nil, None, Outset, Thick, ThickThinLargeGap, ThickThinMediumGap, ThickThinSmallGap, ThinThickLargeGap, ThinThickMediumGap, ThinThickSmallGap, ThinThickThinLargeGap, ThinThickThinMediumGap, ThinThickThinSmallGap, ThreeDEmboss, ThreeDEngrave, Triple, Wave  # noqa: E501

        :param bottom_border_type: The bottom_border_type of this DocxTable.  # noqa: E501
        :type: str
        """

        self._bottom_border_type = bottom_border_type

    @property
    def bottom_border_size(self):
        """Gets the bottom_border_size of this DocxTable.  # noqa: E501

        Width of the border in points (1/72nd of an inch)  # noqa: E501

        :return: The bottom_border_size of this DocxTable.  # noqa: E501
        :rtype: int
        """
        return self._bottom_border_size

    @bottom_border_size.setter
    def bottom_border_size(self, bottom_border_size):
        """Sets the bottom_border_size of this DocxTable.

        Width of the border in points (1/72nd of an inch)  # noqa: E501

        :param bottom_border_size: The bottom_border_size of this DocxTable.  # noqa: E501
        :type: int
        """

        self._bottom_border_size = bottom_border_size

    @property
    def bottom_border_space(self):
        """Gets the bottom_border_space of this DocxTable.  # noqa: E501

        Spacing around the border in points (1/72nd of an inch)  # noqa: E501

        :return: The bottom_border_space of this DocxTable.  # noqa: E501
        :rtype: int
        """
        return self._bottom_border_space

    @bottom_border_space.setter
    def bottom_border_space(self, bottom_border_space):
        """Sets the bottom_border_space of this DocxTable.

        Spacing around the border in points (1/72nd of an inch)  # noqa: E501

        :param bottom_border_space: The bottom_border_space of this DocxTable.  # noqa: E501
        :type: int
        """

        self._bottom_border_space = bottom_border_space

    @property
    def bottom_border_color(self):
        """Gets the bottom_border_color of this DocxTable.  # noqa: E501

        HTML-style color hex value (do not include a #)  # noqa: E501

        :return: The bottom_border_color of this DocxTable.  # noqa: E501
        :rtype: str
        """
        return self._bottom_border_color

    @bottom_border_color.setter
    def bottom_border_color(self, bottom_border_color):
        """Sets the bottom_border_color of this DocxTable.

        HTML-style color hex value (do not include a #)  # noqa: E501

        :param bottom_border_color: The bottom_border_color of this DocxTable.  # noqa: E501
        :type: str
        """

        self._bottom_border_color = bottom_border_color

    @property
    def left_border_type(self):
        """Gets the left_border_type of this DocxTable.  # noqa: E501

        Type for the left border - can be a Single, DashDotStroked, Dashed, DashSmallGap, DotDash, DotDotDash, Dotted, Double, DoubleWave, Inset, Nil, None, Outset, Thick, ThickThinLargeGap, ThickThinMediumGap, ThickThinSmallGap, ThinThickLargeGap, ThinThickMediumGap, ThinThickSmallGap, ThinThickThinLargeGap, ThinThickThinMediumGap, ThinThickThinSmallGap, ThreeDEmboss, ThreeDEngrave, Triple, Wave  # noqa: E501

        :return: The left_border_type of this DocxTable.  # noqa: E501
        :rtype: str
        """
        return self._left_border_type

    @left_border_type.setter
    def left_border_type(self, left_border_type):
        """Sets the left_border_type of this DocxTable.

        Type for the left border - can be a Single, DashDotStroked, Dashed, DashSmallGap, DotDash, DotDotDash, Dotted, Double, DoubleWave, Inset, Nil, None, Outset, Thick, ThickThinLargeGap, ThickThinMediumGap, ThickThinSmallGap, ThinThickLargeGap, ThinThickMediumGap, ThinThickSmallGap, ThinThickThinLargeGap, ThinThickThinMediumGap, ThinThickThinSmallGap, ThreeDEmboss, ThreeDEngrave, Triple, Wave  # noqa: E501

        :param left_border_type: The left_border_type of this DocxTable.  # noqa: E501
        :type: str
        """

        self._left_border_type = left_border_type

    @property
    def left_border_size(self):
        """Gets the left_border_size of this DocxTable.  # noqa: E501

        Width of the border in points (1/72nd of an inch)  # noqa: E501

        :return: The left_border_size of this DocxTable.  # noqa: E501
        :rtype: int
        """
        return self._left_border_size

    @left_border_size.setter
    def left_border_size(self, left_border_size):
        """Sets the left_border_size of this DocxTable.

        Width of the border in points (1/72nd of an inch)  # noqa: E501

        :param left_border_size: The left_border_size of this DocxTable.  # noqa: E501
        :type: int
        """

        self._left_border_size = left_border_size

    @property
    def left_border_space(self):
        """Gets the left_border_space of this DocxTable.  # noqa: E501

        Spacing around the border in points (1/72nd of an inch)  # noqa: E501

        :return: The left_border_space of this DocxTable.  # noqa: E501
        :rtype: int
        """
        return self._left_border_space

    @left_border_space.setter
    def left_border_space(self, left_border_space):
        """Sets the left_border_space of this DocxTable.

        Spacing around the border in points (1/72nd of an inch)  # noqa: E501

        :param left_border_space: The left_border_space of this DocxTable.  # noqa: E501
        :type: int
        """

        self._left_border_space = left_border_space

    @property
    def left_border_color(self):
        """Gets the left_border_color of this DocxTable.  # noqa: E501

        HTML-style color hex value (do not include a #)  # noqa: E501

        :return: The left_border_color of this DocxTable.  # noqa: E501
        :rtype: str
        """
        return self._left_border_color

    @left_border_color.setter
    def left_border_color(self, left_border_color):
        """Sets the left_border_color of this DocxTable.

        HTML-style color hex value (do not include a #)  # noqa: E501

        :param left_border_color: The left_border_color of this DocxTable.  # noqa: E501
        :type: str
        """

        self._left_border_color = left_border_color

    @property
    def right_border_type(self):
        """Gets the right_border_type of this DocxTable.  # noqa: E501

        Type for the right border - can be a Single, DashDotStroked, Dashed, DashSmallGap, DotDash, DotDotDash, Dotted, Double, DoubleWave, Inset, Nil, None, Outset, Thick, ThickThinLargeGap, ThickThinMediumGap, ThickThinSmallGap, ThinThickLargeGap, ThinThickMediumGap, ThinThickSmallGap, ThinThickThinLargeGap, ThinThickThinMediumGap, ThinThickThinSmallGap, ThreeDEmboss, ThreeDEngrave, Triple, Wave  # noqa: E501

        :return: The right_border_type of this DocxTable.  # noqa: E501
        :rtype: str
        """
        return self._right_border_type

    @right_border_type.setter
    def right_border_type(self, right_border_type):
        """Sets the right_border_type of this DocxTable.

        Type for the right border - can be a Single, DashDotStroked, Dashed, DashSmallGap, DotDash, DotDotDash, Dotted, Double, DoubleWave, Inset, Nil, None, Outset, Thick, ThickThinLargeGap, ThickThinMediumGap, ThickThinSmallGap, ThinThickLargeGap, ThinThickMediumGap, ThinThickSmallGap, ThinThickThinLargeGap, ThinThickThinMediumGap, ThinThickThinSmallGap, ThreeDEmboss, ThreeDEngrave, Triple, Wave  # noqa: E501

        :param right_border_type: The right_border_type of this DocxTable.  # noqa: E501
        :type: str
        """

        self._right_border_type = right_border_type

    @property
    def right_border_size(self):
        """Gets the right_border_size of this DocxTable.  # noqa: E501

        Width of the border in points (1/72nd of an inch)  # noqa: E501

        :return: The right_border_size of this DocxTable.  # noqa: E501
        :rtype: int
        """
        return self._right_border_size

    @right_border_size.setter
    def right_border_size(self, right_border_size):
        """Sets the right_border_size of this DocxTable.

        Width of the border in points (1/72nd of an inch)  # noqa: E501

        :param right_border_size: The right_border_size of this DocxTable.  # noqa: E501
        :type: int
        """

        self._right_border_size = right_border_size

    @property
    def right_border_space(self):
        """Gets the right_border_space of this DocxTable.  # noqa: E501

        Spacing around the border in points (1/72nd of an inch)  # noqa: E501

        :return: The right_border_space of this DocxTable.  # noqa: E501
        :rtype: int
        """
        return self._right_border_space

    @right_border_space.setter
    def right_border_space(self, right_border_space):
        """Sets the right_border_space of this DocxTable.

        Spacing around the border in points (1/72nd of an inch)  # noqa: E501

        :param right_border_space: The right_border_space of this DocxTable.  # noqa: E501
        :type: int
        """

        self._right_border_space = right_border_space

    @property
    def right_border_color(self):
        """Gets the right_border_color of this DocxTable.  # noqa: E501

        HTML-style color hex value (do not include a #)  # noqa: E501

        :return: The right_border_color of this DocxTable.  # noqa: E501
        :rtype: str
        """
        return self._right_border_color

    @right_border_color.setter
    def right_border_color(self, right_border_color):
        """Sets the right_border_color of this DocxTable.

        HTML-style color hex value (do not include a #)  # noqa: E501

        :param right_border_color: The right_border_color of this DocxTable.  # noqa: E501
        :type: str
        """

        self._right_border_color = right_border_color

    @property
    def cell_horizontal_border_type(self):
        """Gets the cell_horizontal_border_type of this DocxTable.  # noqa: E501

        Type for the cell horizontal border - can be a Single, DashDotStroked, Dashed, DashSmallGap, DotDash, DotDotDash, Dotted, Double, DoubleWave, Inset, Nil, None, Outset, Thick, ThickThinLargeGap, ThickThinMediumGap, ThickThinSmallGap, ThinThickLargeGap, ThinThickMediumGap, ThinThickSmallGap, ThinThickThinLargeGap, ThinThickThinMediumGap, ThinThickThinSmallGap, ThreeDEmboss, ThreeDEngrave, Triple, Wave  # noqa: E501

        :return: The cell_horizontal_border_type of this DocxTable.  # noqa: E501
        :rtype: str
        """
        return self._cell_horizontal_border_type

    @cell_horizontal_border_type.setter
    def cell_horizontal_border_type(self, cell_horizontal_border_type):
        """Sets the cell_horizontal_border_type of this DocxTable.

        Type for the cell horizontal border - can be a Single, DashDotStroked, Dashed, DashSmallGap, DotDash, DotDotDash, Dotted, Double, DoubleWave, Inset, Nil, None, Outset, Thick, ThickThinLargeGap, ThickThinMediumGap, ThickThinSmallGap, ThinThickLargeGap, ThinThickMediumGap, ThinThickSmallGap, ThinThickThinLargeGap, ThinThickThinMediumGap, ThinThickThinSmallGap, ThreeDEmboss, ThreeDEngrave, Triple, Wave  # noqa: E501

        :param cell_horizontal_border_type: The cell_horizontal_border_type of this DocxTable.  # noqa: E501
        :type: str
        """

        self._cell_horizontal_border_type = cell_horizontal_border_type

    @property
    def cell_horizontal_border_size(self):
        """Gets the cell_horizontal_border_size of this DocxTable.  # noqa: E501

        Width of the border in points (1/72nd of an inch)  # noqa: E501

        :return: The cell_horizontal_border_size of this DocxTable.  # noqa: E501
        :rtype: int
        """
        return self._cell_horizontal_border_size

    @cell_horizontal_border_size.setter
    def cell_horizontal_border_size(self, cell_horizontal_border_size):
        """Sets the cell_horizontal_border_size of this DocxTable.

        Width of the border in points (1/72nd of an inch)  # noqa: E501

        :param cell_horizontal_border_size: The cell_horizontal_border_size of this DocxTable.  # noqa: E501
        :type: int
        """

        self._cell_horizontal_border_size = cell_horizontal_border_size

    @property
    def cell_horizontal_border_space(self):
        """Gets the cell_horizontal_border_space of this DocxTable.  # noqa: E501

        Spacing around the border in points (1/72nd of an inch)  # noqa: E501

        :return: The cell_horizontal_border_space of this DocxTable.  # noqa: E501
        :rtype: int
        """
        return self._cell_horizontal_border_space

    @cell_horizontal_border_space.setter
    def cell_horizontal_border_space(self, cell_horizontal_border_space):
        """Sets the cell_horizontal_border_space of this DocxTable.

        Spacing around the border in points (1/72nd of an inch)  # noqa: E501

        :param cell_horizontal_border_space: The cell_horizontal_border_space of this DocxTable.  # noqa: E501
        :type: int
        """

        self._cell_horizontal_border_space = cell_horizontal_border_space

    @property
    def cell_horizontal_border_color(self):
        """Gets the cell_horizontal_border_color of this DocxTable.  # noqa: E501

        HTML-style color hex value (do not include a #)  # noqa: E501

        :return: The cell_horizontal_border_color of this DocxTable.  # noqa: E501
        :rtype: str
        """
        return self._cell_horizontal_border_color

    @cell_horizontal_border_color.setter
    def cell_horizontal_border_color(self, cell_horizontal_border_color):
        """Sets the cell_horizontal_border_color of this DocxTable.

        HTML-style color hex value (do not include a #)  # noqa: E501

        :param cell_horizontal_border_color: The cell_horizontal_border_color of this DocxTable.  # noqa: E501
        :type: str
        """

        self._cell_horizontal_border_color = cell_horizontal_border_color

    @property
    def cell_vertical_border_type(self):
        """Gets the cell_vertical_border_type of this DocxTable.  # noqa: E501

        Type for the cell vertical border - can be a Single, DashDotStroked, Dashed, DashSmallGap, DotDash, DotDotDash, Dotted, Double, DoubleWave, Inset, Nil, None, Outset, Thick, ThickThinLargeGap, ThickThinMediumGap, ThickThinSmallGap, ThinThickLargeGap, ThinThickMediumGap, ThinThickSmallGap, ThinThickThinLargeGap, ThinThickThinMediumGap, ThinThickThinSmallGap, ThreeDEmboss, ThreeDEngrave, Triple, Wave  # noqa: E501

        :return: The cell_vertical_border_type of this DocxTable.  # noqa: E501
        :rtype: str
        """
        return self._cell_vertical_border_type

    @cell_vertical_border_type.setter
    def cell_vertical_border_type(self, cell_vertical_border_type):
        """Sets the cell_vertical_border_type of this DocxTable.

        Type for the cell vertical border - can be a Single, DashDotStroked, Dashed, DashSmallGap, DotDash, DotDotDash, Dotted, Double, DoubleWave, Inset, Nil, None, Outset, Thick, ThickThinLargeGap, ThickThinMediumGap, ThickThinSmallGap, ThinThickLargeGap, ThinThickMediumGap, ThinThickSmallGap, ThinThickThinLargeGap, ThinThickThinMediumGap, ThinThickThinSmallGap, ThreeDEmboss, ThreeDEngrave, Triple, Wave  # noqa: E501

        :param cell_vertical_border_type: The cell_vertical_border_type of this DocxTable.  # noqa: E501
        :type: str
        """

        self._cell_vertical_border_type = cell_vertical_border_type

    @property
    def cell_vertical_border_size(self):
        """Gets the cell_vertical_border_size of this DocxTable.  # noqa: E501

        Width of the border in points (1/72nd of an inch)  # noqa: E501

        :return: The cell_vertical_border_size of this DocxTable.  # noqa: E501
        :rtype: int
        """
        return self._cell_vertical_border_size

    @cell_vertical_border_size.setter
    def cell_vertical_border_size(self, cell_vertical_border_size):
        """Sets the cell_vertical_border_size of this DocxTable.

        Width of the border in points (1/72nd of an inch)  # noqa: E501

        :param cell_vertical_border_size: The cell_vertical_border_size of this DocxTable.  # noqa: E501
        :type: int
        """

        self._cell_vertical_border_size = cell_vertical_border_size

    @property
    def cell_vertical_border_space(self):
        """Gets the cell_vertical_border_space of this DocxTable.  # noqa: E501

        Spacing around the border in points (1/72nd of an inch)  # noqa: E501

        :return: The cell_vertical_border_space of this DocxTable.  # noqa: E501
        :rtype: int
        """
        return self._cell_vertical_border_space

    @cell_vertical_border_space.setter
    def cell_vertical_border_space(self, cell_vertical_border_space):
        """Sets the cell_vertical_border_space of this DocxTable.

        Spacing around the border in points (1/72nd of an inch)  # noqa: E501

        :param cell_vertical_border_space: The cell_vertical_border_space of this DocxTable.  # noqa: E501
        :type: int
        """

        self._cell_vertical_border_space = cell_vertical_border_space

    @property
    def cell_vertical_border_color(self):
        """Gets the cell_vertical_border_color of this DocxTable.  # noqa: E501

        HTML-style color hex value (do not include a #)  # noqa: E501

        :return: The cell_vertical_border_color of this DocxTable.  # noqa: E501
        :rtype: str
        """
        return self._cell_vertical_border_color

    @cell_vertical_border_color.setter
    def cell_vertical_border_color(self, cell_vertical_border_color):
        """Sets the cell_vertical_border_color of this DocxTable.

        HTML-style color hex value (do not include a #)  # noqa: E501

        :param cell_vertical_border_color: The cell_vertical_border_color of this DocxTable.  # noqa: E501
        :type: str
        """

        self._cell_vertical_border_color = cell_vertical_border_color

    @property
    def start_border_type(self):
        """Gets the start_border_type of this DocxTable.  # noqa: E501

        Type for the start border - can be a Single, DashDotStroked, Dashed, DashSmallGap, DotDash, DotDotDash, Dotted, Double, DoubleWave, Inset, Nil, None, Outset, Thick, ThickThinLargeGap, ThickThinMediumGap, ThickThinSmallGap, ThinThickLargeGap, ThinThickMediumGap, ThinThickSmallGap, ThinThickThinLargeGap, ThinThickThinMediumGap, ThinThickThinSmallGap, ThreeDEmboss, ThreeDEngrave, Triple, Wave  # noqa: E501

        :return: The start_border_type of this DocxTable.  # noqa: E501
        :rtype: str
        """
        return self._start_border_type

    @start_border_type.setter
    def start_border_type(self, start_border_type):
        """Sets the start_border_type of this DocxTable.

        Type for the start border - can be a Single, DashDotStroked, Dashed, DashSmallGap, DotDash, DotDotDash, Dotted, Double, DoubleWave, Inset, Nil, None, Outset, Thick, ThickThinLargeGap, ThickThinMediumGap, ThickThinSmallGap, ThinThickLargeGap, ThinThickMediumGap, ThinThickSmallGap, ThinThickThinLargeGap, ThinThickThinMediumGap, ThinThickThinSmallGap, ThreeDEmboss, ThreeDEngrave, Triple, Wave  # noqa: E501

        :param start_border_type: The start_border_type of this DocxTable.  # noqa: E501
        :type: str
        """

        self._start_border_type = start_border_type

    @property
    def start_border_size(self):
        """Gets the start_border_size of this DocxTable.  # noqa: E501

        Width of the border in points (1/72nd of an inch)  # noqa: E501

        :return: The start_border_size of this DocxTable.  # noqa: E501
        :rtype: int
        """
        return self._start_border_size

    @start_border_size.setter
    def start_border_size(self, start_border_size):
        """Sets the start_border_size of this DocxTable.

        Width of the border in points (1/72nd of an inch)  # noqa: E501

        :param start_border_size: The start_border_size of this DocxTable.  # noqa: E501
        :type: int
        """

        self._start_border_size = start_border_size

    @property
    def start_border_space(self):
        """Gets the start_border_space of this DocxTable.  # noqa: E501

        Spacing around the border in points (1/72nd of an inch)  # noqa: E501

        :return: The start_border_space of this DocxTable.  # noqa: E501
        :rtype: int
        """
        return self._start_border_space

    @start_border_space.setter
    def start_border_space(self, start_border_space):
        """Sets the start_border_space of this DocxTable.

        Spacing around the border in points (1/72nd of an inch)  # noqa: E501

        :param start_border_space: The start_border_space of this DocxTable.  # noqa: E501
        :type: int
        """

        self._start_border_space = start_border_space

    @property
    def start_border_color(self):
        """Gets the start_border_color of this DocxTable.  # noqa: E501

        HTML-style color hex value (do not include a #)  # noqa: E501

        :return: The start_border_color of this DocxTable.  # noqa: E501
        :rtype: str
        """
        return self._start_border_color

    @start_border_color.setter
    def start_border_color(self, start_border_color):
        """Sets the start_border_color of this DocxTable.

        HTML-style color hex value (do not include a #)  # noqa: E501

        :param start_border_color: The start_border_color of this DocxTable.  # noqa: E501
        :type: str
        """

        self._start_border_color = start_border_color

    @property
    def end_border_type(self):
        """Gets the end_border_type of this DocxTable.  # noqa: E501

        Type for the end border - can be a Single, DashDotStroked, Dashed, DashSmallGap, DotDash, DotDotDash, Dotted, Double, DoubleWave, Inset, Nil, None, Outset, Thick, ThickThinLargeGap, ThickThinMediumGap, ThickThinSmallGap, ThinThickLargeGap, ThinThickMediumGap, ThinThickSmallGap, ThinThickThinLargeGap, ThinThickThinMediumGap, ThinThickThinSmallGap, ThreeDEmboss, ThreeDEngrave, Triple, Wave  # noqa: E501

        :return: The end_border_type of this DocxTable.  # noqa: E501
        :rtype: str
        """
        return self._end_border_type

    @end_border_type.setter
    def end_border_type(self, end_border_type):
        """Sets the end_border_type of this DocxTable.

        Type for the end border - can be a Single, DashDotStroked, Dashed, DashSmallGap, DotDash, DotDotDash, Dotted, Double, DoubleWave, Inset, Nil, None, Outset, Thick, ThickThinLargeGap, ThickThinMediumGap, ThickThinSmallGap, ThinThickLargeGap, ThinThickMediumGap, ThinThickSmallGap, ThinThickThinLargeGap, ThinThickThinMediumGap, ThinThickThinSmallGap, ThreeDEmboss, ThreeDEngrave, Triple, Wave  # noqa: E501

        :param end_border_type: The end_border_type of this DocxTable.  # noqa: E501
        :type: str
        """

        self._end_border_type = end_border_type

    @property
    def end_border_size(self):
        """Gets the end_border_size of this DocxTable.  # noqa: E501

        Width of the border in points (1/72nd of an inch)  # noqa: E501

        :return: The end_border_size of this DocxTable.  # noqa: E501
        :rtype: int
        """
        return self._end_border_size

    @end_border_size.setter
    def end_border_size(self, end_border_size):
        """Sets the end_border_size of this DocxTable.

        Width of the border in points (1/72nd of an inch)  # noqa: E501

        :param end_border_size: The end_border_size of this DocxTable.  # noqa: E501
        :type: int
        """

        self._end_border_size = end_border_size

    @property
    def end_border_space(self):
        """Gets the end_border_space of this DocxTable.  # noqa: E501

        Spacing around the border in points (1/72nd of an inch)  # noqa: E501

        :return: The end_border_space of this DocxTable.  # noqa: E501
        :rtype: int
        """
        return self._end_border_space

    @end_border_space.setter
    def end_border_space(self, end_border_space):
        """Sets the end_border_space of this DocxTable.

        Spacing around the border in points (1/72nd of an inch)  # noqa: E501

        :param end_border_space: The end_border_space of this DocxTable.  # noqa: E501
        :type: int
        """

        self._end_border_space = end_border_space

    @property
    def end_border_color(self):
        """Gets the end_border_color of this DocxTable.  # noqa: E501

        HTML-style color hex value (do not include a #)  # noqa: E501

        :return: The end_border_color of this DocxTable.  # noqa: E501
        :rtype: str
        """
        return self._end_border_color

    @end_border_color.setter
    def end_border_color(self, end_border_color):
        """Sets the end_border_color of this DocxTable.

        HTML-style color hex value (do not include a #)  # noqa: E501

        :param end_border_color: The end_border_color of this DocxTable.  # noqa: E501
        :type: str
        """

        self._end_border_color = end_border_color

    @property
    def table_indentation_mode(self):
        """Gets the table_indentation_mode of this DocxTable.  # noqa: E501

        Table indentation type  # noqa: E501

        :return: The table_indentation_mode of this DocxTable.  # noqa: E501
        :rtype: str
        """
        return self._table_indentation_mode

    @table_indentation_mode.setter
    def table_indentation_mode(self, table_indentation_mode):
        """Sets the table_indentation_mode of this DocxTable.

        Table indentation type  # noqa: E501

        :param table_indentation_mode: The table_indentation_mode of this DocxTable.  # noqa: E501
        :type: str
        """

        self._table_indentation_mode = table_indentation_mode

    @property
    def table_indentation_width(self):
        """Gets the table_indentation_width of this DocxTable.  # noqa: E501

        Table indentation width  # noqa: E501

        :return: The table_indentation_width of this DocxTable.  # noqa: E501
        :rtype: int
        """
        return self._table_indentation_width

    @table_indentation_width.setter
    def table_indentation_width(self, table_indentation_width):
        """Sets the table_indentation_width of this DocxTable.

        Table indentation width  # noqa: E501

        :param table_indentation_width: The table_indentation_width of this DocxTable.  # noqa: E501
        :type: int
        """

        self._table_indentation_width = table_indentation_width

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(DocxTable, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DocxTable):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    convertapi

    Convert API lets you effortlessly convert file formats and types.  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import cloudmersive_convert_api_client
from cloudmersive_convert_api_client.api.edit_pdf_api import EditPdfApi  # noqa: E501
from cloudmersive_convert_api_client.rest import ApiException


class TestEditPdfApi(unittest.TestCase):
    """EditPdfApi unit test stubs"""

    def setUp(self):
        self.api = cloudmersive_convert_api_client.api.edit_pdf_api.EditPdfApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_edit_pdf_encrypt(self):
        """Test case for edit_pdf_encrypt

        Encrypt and password-protect a PDF  # noqa: E501
        """
        pass

    def test_edit_pdf_set_permissions(self):
        """Test case for edit_pdf_set_permissions

        Encrypt, password-protect and set restricted permissions on a PDF  # noqa: E501
        """
        pass

    def test_edit_pdf_watermark_text(self):
        """Test case for edit_pdf_watermark_text

        Add a text watermark to a PDF  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    convertapi

    Convert API lets you effortlessly convert file formats and types.  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class DocxTableCell(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'cell_index': 'int',
        'path': 'str',
        'paragraphs': 'list[DocxParagraph]',
        'cell_shading_color': 'str',
        'cell_shading_fill': 'str',
        'cell_shading_pattern': 'str',
        'cell_width_mode': 'str',
        'cell_width': 'str'
    }

    attribute_map = {
        'cell_index': 'CellIndex',
        'path': 'Path',
        'paragraphs': 'Paragraphs',
        'cell_shading_color': 'CellShadingColor',
        'cell_shading_fill': 'CellShadingFill',
        'cell_shading_pattern': 'CellShadingPattern',
        'cell_width_mode': 'CellWidthMode',
        'cell_width': 'CellWidth'
    }

    def __init__(self, cell_index=None, path=None, paragraphs=None, cell_shading_color=None, cell_shading_fill=None, cell_shading_pattern=None, cell_width_mode=None, cell_width=None):  # noqa: E501
        """DocxTableCell - a model defined in Swagger"""  # noqa: E501

        self._cell_index = None
        self._path = None
        self._paragraphs = None
        self._cell_shading_color = None
        self._cell_shading_fill = None
        self._cell_shading_pattern = None
        self._cell_width_mode = None
        self._cell_width = None
        self.discriminator = None

        if cell_index is not None:
            self.cell_index = cell_index
        if path is not None:
            self.path = path
        if paragraphs is not None:
            self.paragraphs = paragraphs
        if cell_shading_color is not None:
            self.cell_shading_color = cell_shading_color
        if cell_shading_fill is not None:
            self.cell_shading_fill = cell_shading_fill
        if cell_shading_pattern is not None:
            self.cell_shading_pattern = cell_shading_pattern
        if cell_width_mode is not None:
            self.cell_width_mode = cell_width_mode
        if cell_width is not None:
            self.cell_width = cell_width

    @property
    def cell_index(self):
        """Gets the cell_index of this DocxTableCell.  # noqa: E501

        The index of the cell, 0-based  # noqa: E501

        :return: The cell_index of this DocxTableCell.  # noqa: E501
        :rtype: int
        """
        return self._cell_index

    @cell_index.setter
    def cell_index(self, cell_index):
        """Sets the cell_index of this DocxTableCell.

        The index of the cell, 0-based  # noqa: E501

        :param cell_index: The cell_index of this DocxTableCell.  # noqa: E501
        :type: int
        """

        self._cell_index = cell_index

    @property
    def path(self):
        """Gets the path of this DocxTableCell.  # noqa: E501

        The Path of the location of this object; leave blank for new tables  # noqa: E501

        :return: The path of this DocxTableCell.  # noqa: E501
        :rtype: str
        """
        return self._path

    @path.setter
    def path(self, path):
        """Sets the path of this DocxTableCell.

        The Path of the location of this object; leave blank for new tables  # noqa: E501

        :param path: The path of this DocxTableCell.  # noqa: E501
        :type: str
        """

        self._path = path

    @property
    def paragraphs(self):
        """Gets the paragraphs of this DocxTableCell.  # noqa: E501

        Paragraphs inside the cell; this is where the contents of the cell are stored  # noqa: E501

        :return: The paragraphs of this DocxTableCell.  # noqa: E501
        :rtype: list[DocxParagraph]
        """
        return self._paragraphs

    @paragraphs.setter
    def paragraphs(self, paragraphs):
        """Sets the paragraphs of this DocxTableCell.

        Paragraphs inside the cell; this is where the contents of the cell are stored  # noqa: E501

        :param paragraphs: The paragraphs of this DocxTableCell.  # noqa: E501
        :type: list[DocxParagraph]
        """

        self._paragraphs = paragraphs

    @property
    def cell_shading_color(self):
        """Gets the cell_shading_color of this DocxTableCell.  # noqa: E501

        Color of the cell shading  # noqa: E501

        :return: The cell_shading_color of this DocxTableCell.  # noqa: E501
        :rtype: str
        """
        return self._cell_shading_color

    @cell_shading_color.setter
    def cell_shading_color(self, cell_shading_color):
        """Sets the cell_shading_color of this DocxTableCell.

        Color of the cell shading  # noqa: E501

        :param cell_shading_color: The cell_shading_color of this DocxTableCell.  # noqa: E501
        :type: str
        """

        self._cell_shading_color = cell_shading_color

    @property
    def cell_shading_fill(self):
        """Gets the cell_shading_fill of this DocxTableCell.  # noqa: E501

        Fill of the cell shading  # noqa: E501

        :return: The cell_shading_fill of this DocxTableCell.  # noqa: E501
        :rtype: str
        """
        return self._cell_shading_fill

    @cell_shading_fill.setter
    def cell_shading_fill(self, cell_shading_fill):
        """Sets the cell_shading_fill of this DocxTableCell.

        Fill of the cell shading  # noqa: E501

        :param cell_shading_fill: The cell_shading_fill of this DocxTableCell.  # noqa: E501
        :type: str
        """

        self._cell_shading_fill = cell_shading_fill

    @property
    def cell_shading_pattern(self):
        """Gets the cell_shading_pattern of this DocxTableCell.  # noqa: E501

        Pattern of the cell shading  # noqa: E501

        :return: The cell_shading_pattern of this DocxTableCell.  # noqa: E501
        :rtype: str
        """
        return self._cell_shading_pattern

    @cell_shading_pattern.setter
    def cell_shading_pattern(self, cell_shading_pattern):
        """Sets the cell_shading_pattern of this DocxTableCell.

        Pattern of the cell shading  # noqa: E501

        :param cell_shading_pattern: The cell_shading_pattern of this DocxTableCell.  # noqa: E501
        :type: str
        """

        self._cell_shading_pattern = cell_shading_pattern

    @property
    def cell_width_mode(self):
        """Gets the cell_width_mode of this DocxTableCell.  # noqa: E501

        Width mode of the cell; can be auto (for automatic) or manual  # noqa: E501

        :return: The cell_width_mode of this DocxTableCell.  # noqa: E501
        :rtype: str
        """
        return self._cell_width_mode

    @cell_width_mode.setter
    def cell_width_mode(self, cell_width_mode):
        """Sets the cell_width_mode of this DocxTableCell.

        Width mode of the cell; can be auto (for automatic) or manual  # noqa: E501

        :param cell_width_mode: The cell_width_mode of this DocxTableCell.  # noqa: E501
        :type: str
        """

        self._cell_width_mode = cell_width_mode

    @property
    def cell_width(self):
        """Gets the cell_width of this DocxTableCell.  # noqa: E501

        Width of the cell  # noqa: E501

        :return: The cell_width of this DocxTableCell.  # noqa: E501
        :rtype: str
        """
        return self._cell_width

    @cell_width.setter
    def cell_width(self, cell_width):
        """Sets the cell_width of this DocxTableCell.

        Width of the cell  # noqa: E501

        :param cell_width: The cell_width of this DocxTableCell.  # noqa: E501
        :type: str
        """

        self._cell_width = cell_width

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(DocxTableCell, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DocxTableCell):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    convertapi

    Convert API lets you effortlessly convert file formats and types.  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class EmlToHtmlResult(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'successful': 'bool',
        'content': 'str',
        'body': 'str',
        '_from': 'str',
        'to': 'str',
        'cc': 'str',
        'date_sent': 'str',
        'subject': 'str',
        'attachments': 'list[EmlAttachment]'
    }

    attribute_map = {
        'successful': 'Successful',
        'content': 'Content',
        'body': 'Body',
        '_from': 'From',
        'to': 'To',
        'cc': 'Cc',
        'date_sent': 'DateSent',
        'subject': 'Subject',
        'attachments': 'Attachments'
    }

    def __init__(self, successful=None, content=None, body=None, _from=None, to=None, cc=None, date_sent=None, subject=None, attachments=None):  # noqa: E501
        """EmlToHtmlResult - a model defined in Swagger"""  # noqa: E501

        self._successful = None
        self._content = None
        self._body = None
        self.__from = None
        self._to = None
        self._cc = None
        self._date_sent = None
        self._subject = None
        self._attachments = None
        self.discriminator = None

        if successful is not None:
            self.successful = successful
        if content is not None:
            self.content = content
        if body is not None:
            self.body = body
        if _from is not None:
            self._from = _from
        if to is not None:
            self.to = to
        if cc is not None:
            self.cc = cc
        if date_sent is not None:
            self.date_sent = date_sent
        if subject is not None:
            self.subject = subject
        if attachments is not None:
            self.attachments = attachments

    @property
    def successful(self):
        """Gets the successful of this EmlToHtmlResult.  # noqa: E501

        True if the operation was successful, false otherwise  # noqa: E501

        :return: The successful of this EmlToHtmlResult.  # noqa: E501
        :rtype: bool
        """
        return self._successful

    @successful.setter
    def successful(self, successful):
        """Sets the successful of this EmlToHtmlResult.

        True if the operation was successful, false otherwise  # noqa: E501

        :param successful: The successful of this EmlToHtmlResult.  # noqa: E501
        :type: bool
        """

        self._successful = successful

    @property
    def content(self):
        """Gets the content of this EmlToHtmlResult.  # noqa: E501

        An HTML string version of the EML file  # noqa: E501

        :return: The content of this EmlToHtmlResult.  # noqa: E501
        :rtype: str
        """
        return self._content

    @content.setter
    def content(self, content):
        """Sets the content of this EmlToHtmlResult.

        An HTML string version of the EML file  # noqa: E501

        :param content: The content of this EmlToHtmlResult.  # noqa: E501
        :type: str
        """

        self._content = content

    @property
    def body(self):
        """Gets the body of this EmlToHtmlResult.  # noqa: E501

        The main body of the EML file's email as an HTML string  # noqa: E501

        :return: The body of this EmlToHtmlResult.  # noqa: E501
        :rtype: str
        """
        return self._body

    @body.setter
    def body(self, body):
        """Sets the body of this EmlToHtmlResult.

        The main body of the EML file's email as an HTML string  # noqa: E501

        :param body: The body of this EmlToHtmlResult.  # noqa: E501
        :type: str
        """

        self._body = body

    @property
    def _from(self):
        """Gets the _from of this EmlToHtmlResult.  # noqa: E501

        The From sender of the EML file's email  # noqa: E501

        :return: The _from of this EmlToHtmlResult.  # noqa: E501
        :rtype: str
        """
        return self.__from

    @_from.setter
    def _from(self, _from):
        """Sets the _from of this EmlToHtmlResult.

        The From sender of the EML file's email  # noqa: E501

        :param _from: The _from of this EmlToHtmlResult.  # noqa: E501
        :type: str
        """

        self.__from = _from

    @property
    def to(self):
        """Gets the to of this EmlToHtmlResult.  # noqa: E501

        The To recipients of the EML file's email  # noqa: E501

        :return: The to of this EmlToHtmlResult.  # noqa: E501
        :rtype: str
        """
        return self._to

    @to.setter
    def to(self, to):
        """Sets the to of this EmlToHtmlResult.

        The To recipients of the EML file's email  # noqa: E501

        :param to: The to of this EmlToHtmlResult.  # noqa: E501
        :type: str
        """

        self._to = to

    @property
    def cc(self):
        """Gets the cc of this EmlToHtmlResult.  # noqa: E501

        The CC recipients of the EML file's email  # noqa: E501

        :return: The cc of this EmlToHtmlResult.  # noqa: E501
        :rtype: str
        """
        return self._cc

    @cc.setter
    def cc(self, cc):
        """Sets the cc of this EmlToHtmlResult.

        The CC recipients of the EML file's email  # noqa: E501

        :param cc: The cc of this EmlToHtmlResult.  # noqa: E501
        :type: str
        """

        self._cc = cc

    @property
    def date_sent(self):
        """Gets the date_sent of this EmlToHtmlResult.  # noqa: E501

        The date and time that the EML file's email was sent  # noqa: E501

        :return: The date_sent of this EmlToHtmlResult.  # noqa: E501
        :rtype: str
        """
        return self._date_sent

    @date_sent.setter
    def date_sent(self, date_sent):
        """Sets the date_sent of this EmlToHtmlResult.

        The date and time that the EML file's email was sent  # noqa: E501

        :param date_sent: The date_sent of this EmlToHtmlResult.  # noqa: E501
        :type: str
        """

        self._date_sent = date_sent

    @property
    def subject(self):
        """Gets the subject of this EmlToHtmlResult.  # noqa: E501

        The subject of the EML file's email  # noqa: E501

        :return: The subject of this EmlToHtmlResult.  # noqa: E501
        :rtype: str
        """
        return self._subject

    @subject.setter
    def subject(self, subject):
        """Sets the subject of this EmlToHtmlResult.

        The subject of the EML file's email  # noqa: E501

        :param subject: The subject of this EmlToHtmlResult.  # noqa: E501
        :type: str
        """

        self._subject = subject

    @property
    def attachments(self):
        """Gets the attachments of this EmlToHtmlResult.  # noqa: E501

        List of all attachments for the EML file  # noqa: E501

        :return: The attachments of this EmlToHtmlResult.  # noqa: E501
        :rtype: list[EmlAttachment]
        """
        return self._attachments

    @attachments.setter
    def attachments(self, attachments):
        """Sets the attachments of this EmlToHtmlResult.

        List of all attachments for the EML file  # noqa: E501

        :param attachments: The attachments of this EmlToHtmlResult.  # noqa: E501
        :type: list[EmlAttachment]
        """

        self._attachments = attachments

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(EmlToHtmlResult, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, EmlToHtmlResult):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
